==> kubernetes-model-apiextensions-5.9.0-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1/CustomResourceConversionFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface CustomResourceConversionFluent<A extends io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getStrategy();
  public A withStrategy(java.lang.String strategy);
  public java.lang.Boolean hasStrategy();
  
  /**
   * Method is deprecated. use withStrategy instead.
   */
  @java.lang.Deprecated
  public A withNewStrategy(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildWebhook instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversion getWebhook();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversion buildWebhook();
  public A withWebhook(io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversion webhook);
  public java.lang.Boolean hasWebhook();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluent.WebhookNested<A> withNewWebhook();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluent.WebhookNested<A> withNewWebhookLike(io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversion item);
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluent.WebhookNested<A> editWebhook();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluent.WebhookNested<A> editOrNewWebhook();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluent.WebhookNested<A> editOrNewWebhookLike(io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversion item);
  public interface WebhookNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversionFluent<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluent.WebhookNested<N>>{
    public N and();
    public N endWebhook();
    
  }
  
}

==> kubernetes-model-apiextensions-5.12.4-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1/CustomResourceConversionFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface CustomResourceConversionFluent<A extends io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getStrategy();
  public A withStrategy(java.lang.String strategy);
  public java.lang.Boolean hasStrategy();
  
  /**
   * Method is deprecated. use withStrategy instead.
   */
  @java.lang.Deprecated
  public A withNewStrategy(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildWebhook instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversion getWebhook();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversion buildWebhook();
  public A withWebhook(io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversion webhook);
  public java.lang.Boolean hasWebhook();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluent.WebhookNested<A> withNewWebhook();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluent.WebhookNested<A> withNewWebhookLike(io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversion item);
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluent.WebhookNested<A> editWebhook();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluent.WebhookNested<A> editOrNewWebhook();
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluent.WebhookNested<A> editOrNewWebhookLike(io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversion item);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface WebhookNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.apiextensions.v1.WebhookConversionFluent<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceConversionFluent.WebhookNested<N>>{
    public N and();
    public N endWebhook();
    
  }
  
}
